Overview
========

The module computes various polynomials useful for `webnucleo <https://webnucleo.readthedocs.io>`_ projects.  In particular, the package has modules to compute symmetric and Bell polynomials for input sets of variables.  For the complete Bell polynomials, the package also has a routine to invert an appropriate set of Bell polynomials to find the variables that would give rise to those polynomials.

Installation
------------

Install from `PyPI <https://pypi.org/project/wnpoly>`_ with pip by
typing in your favorite terminal::

    $ pip install wnpoly

Usage
-----

To learn how to use the package, follow the Jupyter notebook
`tutorial <https://github.com/mbradle/wnpoly/blob/main/tutorial/>`_.

Authors
-------

- Bradley S. Meyer <mbradle@g.clemson.edu>
- Ian Reistroffer <ireistr@g.clemson.edu>

Contribute
----------

- Issue Tracker: `<https://github.com/mbradle/wnpoly/issues/>`_
- Source Code: `<https://github.com/mbradle/wnpoly/>`_

License
-------

The project is licensed under the GNU Public License v3 (or later).

Documentation
-------------

The project documentation is available at `<https://wnpoly.readthedocs.io>`_.

